@@ -4,7 +4,7 @@ import (
 	_ "embed"
 
 	"github.com/livebud/bud/internal/gotemplate"
-	"github.com/livebud/bud/package/budfs"
+	"github.com/livebud/bud/package/genfs"
 	"github.com/livebud/bud/package/gomod"
 	"github.com/livebud/bud/package/parser"
 )
@@ -28,7 +28,7 @@ type Generator struct {
 	parser *parser.Parser
 }
 
-func (g *Generator) GenerateFile(fsys budfs.FS, file *budfs.File) error {
+func (g *Generator) GenerateFile(fsys genfs.FS, file *genfs.File) error {
 	state, err := Load(fsys, g.module, g.parser)
 	if err != nil {
 		return err
