@@ -5,16 +5,21 @@ import (
 	"errors"
 	"io"
 	"io/fs"
-	"net/http/httptest"
 	"os"
 	"testing"
 	"time"
 
-	"github.com/livebud/bud/package/budfs"
+	"github.com/livebud/bud/framework"
+	"github.com/livebud/bud/internal/dag"
+
+	"github.com/livebud/bud/package/genfs"
+	"github.com/livebud/bud/package/socket"
+
 	"github.com/livebud/bud/package/log/testlog"
 
 	"github.com/livebud/bud/framework/transform/transformrt"
 	"github.com/livebud/bud/framework/view/dom"
+	"github.com/livebud/bud/framework/view/nodemodules"
 	"github.com/livebud/bud/framework/view/ssr"
 	"github.com/livebud/bud/internal/is"
 	"github.com/livebud/bud/internal/pubsub"
@@ -27,7 +32,8 @@ import (
 	"github.com/livebud/bud/package/svelte"
 )
 
-func loadServer(bus pubsub.Client, dir string) (*httptest.Server, error) {
+func loadServer(bus pubsub.Client, dir string) (*budsvr.Server, error) {
+	flag := new(framework.Flag)
 	log := testlog.New()
 	vm, err := v8.Load()
 	if err != nil {
@@ -37,7 +43,7 @@ func loadServer(bus pubsub.Client, dir string) (*httptest.Server, error) {
 	if err != nil {
 		return nil, err
 	}
-	transforms, err := transformrt.Load(svelte.NewTransformable(svelteCompiler))
+	transforms, err := transformrt.Default(log, svelteCompiler)
 	if err != nil {
 		return nil, err
 	}
@@ -45,91 +51,19 @@ func loadServer(bus pubsub.Client, dir string) (*httptest.Server, error) {
 	if err != nil {
 		return nil, err
 	}
-	bfs := budfs.New(module, log)
-	bfs.FileServer("bud/view", dom.New(module, transforms.DOM))
-	bfs.FileServer("bud/node_modules", dom.NodeModules(module))
-	bfs.FileGenerator("bud/view/_ssr.js", ssr.New(module, transforms.SSR))
-	handler := budsvr.New(bfs, bus, log, vm)
-	return httptest.NewServer(handler), nil
-}
-
-func TestRender(t *testing.T) {
-	ctx := context.Background()
-	is := is.New(t)
-	log := testlog.New()
-	dir := t.TempDir()
-	td := testdir.New(dir)
-	td.Files["view/index.svelte"] = `
-		<script>
-			export let _string = "cupcake"
-		</script>
-		<h1>Hello, {_string}!</h1>
-	`
-	td.NodeModules["svelte"] = versions.Svelte
-	is.NoErr(td.Write(ctx))
-	ps := pubsub.New()
-	server, err := loadServer(ps, dir)
-	is.NoErr(err)
-	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
-	is.NoErr(err)
-	res, err := client.Render("/", map[string]interface{}{
-		"_string": "marshmallow",
-	})
-	is.NoErr(err)
-	is.Equal(res.Status, 200)
-	is.Equal(len(res.Headers), 1)
-	is.Equal(res.Headers["Content-Type"], "text/html")
-	is.In(res.Body, `<h1>Hello, marshmallow!</h1>`)
-}
-
-func TestRenderNested(t *testing.T) {
-	ctx := context.Background()
-	is := is.New(t)
-	log := testlog.New()
-	dir := t.TempDir()
-	td := testdir.New(dir)
-	td.Files["view/posts/comments/edit.svelte"] = `
-		<script>
-			export let _string = "cupcake"
-		</script>
-		<h1>Hello, {_string}!</h1>
-	`
-	td.NodeModules["svelte"] = versions.Svelte
-	is.NoErr(td.Write(ctx))
-	ps := pubsub.New()
-	server, err := loadServer(ps, dir)
-	is.NoErr(err)
-	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
-	is.NoErr(err)
-	res, err := client.Render("/posts/:post_id/comments/:id/edit", map[string]interface{}{
-		"_string": "marshmallow",
-	})
-	is.NoErr(err)
-	is.Equal(res.Status, 200)
-	is.Equal(len(res.Headers), 1)
-	is.Equal(res.Headers["Content-Type"], "text/html")
-	is.In(res.Body, `<h1>Hello, marshmallow!</h1>`)
-}
-
-func TestRender404(t *testing.T) {
-	t.SkipNow()
-	ctx := context.Background()
-	is := is.New(t)
-	log := testlog.New()
-	dir := t.TempDir()
-	td := testdir.New(dir)
-	is.NoErr(td.Write(ctx))
-	ps := pubsub.New()
-	server, err := loadServer(ps, dir)
-	is.NoErr(err)
-	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
-	is.NoErr(err)
-	res, err := client.Render("/", map[string]interface{}{})
-	is.True(errors.Is(err, fs.ErrNotExist))
-	is.Equal(res, nil)
+	budln, err := socket.Listen(":0")
+	if err != nil {
+		return nil, err
+	}
+	cache, err := dag.Load(log, ":memory:")
+	if err != nil {
+		return nil, err
+	}
+	gfs := genfs.New(cache, module, log)
+	gfs.FileServer("bud/view", dom.New(module, transforms))
+	gfs.FileServer("bud/node_modules", nodemodules.New(module))
+	gfs.FileGenerator("bud/view/_ssr.js", ssr.New(module, transforms))
+	return budsvr.New(budln, bus, flag, gfs, log, vm), nil
 }
 
 func TestOpen(t *testing.T) {
@@ -150,8 +84,9 @@ func TestOpen(t *testing.T) {
 	bus := pubsub.New()
 	server, err := loadServer(bus, dir)
 	is.NoErr(err)
+	server.Start(ctx)
 	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
+	client, err := budhttp.Load(log, server.Address())
 	is.NoErr(err)
 
 	// Check the entrypoint
@@ -208,8 +143,9 @@ func TestOpen404(t *testing.T) {
 	bus := pubsub.New()
 	server, err := loadServer(bus, dir)
 	is.NoErr(err)
+	server.Start(ctx)
 	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
+	client, err := budhttp.Load(log, server.Address())
 	is.NoErr(err)
 	file, err := client.Open("public/favicon.ico")
 	is.True(errors.Is(err, fs.ErrNotExist))
@@ -226,8 +162,9 @@ func TestEvents(t *testing.T) {
 	ps := pubsub.New()
 	server, err := loadServer(ps, dir)
 	is.NoErr(err)
+	server.Start(ctx)
 	defer server.Close()
-	client, err := budhttp.Load(log, server.URL)
+	client, err := budhttp.Load(log, server.Address())
 	is.NoErr(err)
 	sub := ps.Subscribe("ready")
 	defer sub.Close()
@@ -240,3 +177,45 @@ func TestEvents(t *testing.T) {
 		t.Fatalf("missing event")
 	}
 }
+
+func TestScript(t *testing.T) {
+	ctx := context.Background()
+	is := is.New(t)
+	log := testlog.New()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	is.NoErr(td.Write(ctx))
+	ps := pubsub.New()
+	server, err := loadServer(ps, dir)
+	is.NoErr(err)
+	server.Start(ctx)
+	defer server.Close()
+	client, err := budhttp.Load(log, server.Address())
+	is.NoErr(err)
+	err = client.Script("script.js", "function a() { return 1 }")
+	is.NoErr(err)
+	err = client.Script("script.js", "function b() { return 1")
+	is.True(err != nil)
+	is.In(err.Error(), "SyntaxError: Unexpected end of input")
+}
+
+func TestScriptEval(t *testing.T) {
+	ctx := context.Background()
+	is := is.New(t)
+	log := testlog.New()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	is.NoErr(td.Write(ctx))
+	ps := pubsub.New()
+	server, err := loadServer(ps, dir)
+	is.NoErr(err)
+	server.Start(ctx)
+	defer server.Close()
+	client, err := budhttp.Load(log, server.Address())
+	is.NoErr(err)
+	err = client.Script("script.js", "function a() { return 1 }")
+	is.NoErr(err)
+	val, err := client.Eval("script.js", "a()")
+	is.NoErr(err)
+	is.Equal(val, "1")
+}
